macro_rules! span {
($source_id:expr, $l:expr, $r:expr) => { ... };
($source_id:expr, $i:expr) => { ... };
}Expand description
Simple macro used in the grammar definition for constructing spans
macro_rules! span {
($source_id:expr, $l:expr, $r:expr) => { ... };
($source_id:expr, $i:expr) => { ... };
}Simple macro used in the grammar definition for constructing spans