pub enum Pattern<'a> {
Empty(AlwaysMatch),
Substring(SubstringMatcher<'a>),
Regex(RegexMatcher<'a>),
Smart(SmartMatcher<'a>),
Whitespace(AsciiWhitespaceMatcher),
}Expand description
The compiled form of CheckPattern
Variants
Empty(AlwaysMatch)
This pattern always succeeds
Substring(SubstringMatcher<'a>)
A literal string that must occur somewhere in the input
Regex(RegexMatcher<'a>)
A regular expression that must occur somewhere in the input
Smart(SmartMatcher<'a>)
A hybrid match expression that must occur somewhere in the input
Whitespace(AsciiWhitespaceMatcher)
A matcher for pure ASCII whitespace patterns
Implementations
Sourceimpl<'a> Pattern<'a>
impl<'a> Pattern<'a>
pub fn into_matcher_mut(self) -> AnyMatcherMut<'a>
pub fn from_prefix( prefix: PatternPrefix<'a>, config: &Config, ) -> DiagResult<Self>
pub fn compile(pattern: CheckPattern<'a>, config: &Config) -> DiagResult<Self>
pub fn compile_static( span: SourceSpan, pattern: CheckPattern<'a>, config: &Config, ) -> DiagResult<SimpleMatcher<'a>>
pub fn compile_literal( pattern: CheckPattern<'a>, config: &Config, ) -> DiagResult<Self>