pub struct Options {Show 14 fields
pub allow_empty: bool,
pub check_prefixes: Vec<Symbol>,
pub comment_prefixes: Vec<Symbol>,
pub allow_unused_prefixes: bool,
pub strict_whitespace: bool,
pub match_full_lines: bool,
pub ignore_case: bool,
pub implicit_check_not: Vec<Symbol>,
pub dump_input: Dump,
pub dump_input_filter: DumpFilter,
pub enable_var_scope: bool,
pub variables: Vec<CliVariable>,
pub verbose: u8,
pub color: ColorChoice,
}Expand description
FileCheck reads two files, one from standard input, and one specified on the command line; and uses one to verify the other.
Fields
allow_empty: boolAllow checking empty input. By default, empty input is rejected.
check_prefixes: Vec<Symbol>Which prefixes to treat as directives.
For example, in the directive CHECK-SAME, CHECK is the prefix.
comment_prefixes: Vec<Symbol>Which prefixes to treat as comments.
All content on a line following a comment directive is ignored, up to the next newline.
allow_unused_prefixes: boolIf specifying multiple check prefixes, this controls whether or not to raise an error if one of the prefixes is missing in the test file.
strict_whitespace: boolDisable default canonicalization of whitespace.
By default, FileCheck canonicalizes horizontal whitespace (spaces and tabs) which causes it to ignore these differences (a space will match a tab).
This flag disables horizontal whitespace canonicalization.
Newlines are always canonicalized to LF regardless of this setting.
match_full_lines: boolThis flag changes the default matching behavior to require all positive
matches to cover an entire line. Leading/trailing whitespace is ignored
unless --strict-whitespace is also specified.
By default, FileCheck allows matches of anywhere on a line, so by setting
this, you effectively insert {{^.*}} or {{^}} before, and {{[*$]}}
or {{$}} after every positive check pattern.
NOTE Negative matches, i.e CHECK-NOT are not affected by this option.
ignore_case: boolDisable case-sensitive matching
implicit_check_not: Vec<Symbol>Adds implicit negative checks for the specified patterns between positive checks.
This option allows writing stricter tests without polluting them with CHECK-NOTs.
For example, --implicit-check-not warning: can be useful when testing diagnostic
messages from tools that don’t have an option similar to clang -verify. With this
option FileCheck will verify that input does not contain warnings not covered by any
CHECK: patterns.
dump_input: DumpDump input to stderr, adding annotations representing currently enabled diagnostics.
dump_input_filter: DumpFilterSpecify the parts of the input to dump when --dump-input is set.
When specified, print only input lines of KIND, plus any context specified by --dump-input-context.
Defaults to error when --dump-input=fail, and all when --dump-input=always
enable_var_scope: boolEnables scope for regex variables
Variables with names that start with $ are considered global, and remain set throughout the file
All other variables get undefined after each encountered CHECK-LABEL
variables: Vec<CliVariable>Set a pattern variable VAR with value VALUE that can be used in CHECK: lines
You must specify each one in key=value format
verbose: u8Set the verbosity level.
If specified a single time, it causes filecheck to print good directive pattern matches
If specified multiple times, filecheck will emit internal diagnostics to aid in troubleshooting.
If --dump-input=fail or --dump-input=always, add information as input annotations instead.
color: ColorChoiceWhether, and how, to color terminal output
Implementations